Index: trunk/psLib/src/sys/psLine.h
===================================================================
--- trunk/psLib/src/sys/psLine.h	(revision 7380)
+++ trunk/psLib/src/sys/psLine.h	(revision 7847)
@@ -7,21 +7,44 @@
 #define PS_LINE_H
 
-// structure to carry a dynamic string
+/** Structure to carry a dynamic string */
 typedef struct
 {
-    long NLINE;                 // allocated length
-    long Nline;                 // current length
-    char *line;                 // character string data
+    long NLINE;                        ///< allocated length
+    long Nline;                        ///< current length
+    char *line;                        ///< character string data
 }
 psLine;
 
-// allocate a line object of length Nline
-psLine *psLineAlloc(long Nline);
+/** Allocates a line object of length Nline
+ *
+ *  @return psLine*:        the newly allocated line object.
+*/
+psLine *psLineAlloc(
+    long Nline                         ///<
+);
 
-// (re-)init the line
-bool psLineInit(psLine *line);
+/** Initializes or re-initializes a line.
+ *
+ *  Initializes or re-initializes a line, setting the current length to zero and setting
+ *  the string data values to 0.  If the function is passed NULL, false is returned.
+ *
+ *  @return bool:       True if successful, otherwise false.
+*/
+bool psLineInit(
+    psLine *line                       ///<
+);
 
-// add the new string segment to the line
-bool psLineAdd(psLine *line, const char *format, ...);
+/** Adds the line segment to the string.
+ *
+ *  Appends a line segment to the string, returning false if the new segment would
+ *  overflow the allocated string length.
+ *
+ *  @return bool:        True if successful, otherwise false.
+*/
+bool psLineAdd(
+    psLine *line,                      ///< the line segment to append
+    const char *format,                ///< printf-style format of line
+    ...                                ///< any parameters required in format
+);
 
 #endif /* PS_LINE_H */
